'use strict';
/* eslint require-jsdoc: 0*/

var debounce = require('lodash.debounce');

var _require = require('../commander'),
    program = _require.program;

var cmdPrefix = function cmdPrefix(cmd) {
	return 'lerna-terminal' + (cmd ? '/' + cmd : '') + '~$ ';
};

var _print = debounce(function (value, stdin) {
	/* istanbul ignore next */
	if (process.env.NODE_ENV !== 'ci' && process.env.NODE_ENV !== 'test') {
		process.stdout.write('\x1Bc');
	}
	process.stdout.write(value);
	process.stdout.write(stdin);
}, 17);

var state = {};
var uiState = {
	prefix: cmdPrefix(''),
	buffer: '',
	entered: '',
	onChange: function onChange(value) {
		this.entered = value;
		this.print(this.buffer);
	},
	print: function print(value) {
		if (typeof this.focus === 'string' && this.focus !== '' && this.focus !== 'all') {
			this.prefix = cmdPrefix(this.focus);
		} else {
			this.prefix = cmdPrefix('');
		}
		this.buffer = value;

		_print(value, this.prefix + this.entered);
	},
	clearBuffer: function clearBuffer() {
		this.buffer = '';
	},

	notifications: [],
	help: false
};

/**
 * @description prepares the initial store
 * @returns {void}
 **/
function provideStore() {
	/* istanbul ignore next */
	uiState.focus = program.focus ? program.focus : 'all';
}

/**
 * @returns {Object} state
 **/
function getState() {
	return state;
}
/**
 * @returns {Object} uiState
 **/
function getUiState() {
	return uiState;
}

module.exports = { state: state, getState: getState, uiState: uiState, getUiState: getUiState, provideStore: provideStore };